@@ -1,5 +1,5 @@
 
-package org.virtualbox_7_1.jaxws;
+package org.virtualbox_7_2.jaxws;
 
 import javax.xml.bind.annotation.XmlEnum;
 import javax.xml.bind.annotation.XmlEnumValue;
@@ -15,7 +15,6 @@ import javax.xml.bind.annotation.XmlType;
  * &lt;simpleType name="GraphicsFeature">
  *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
  *     &lt;enumeration value="None"/>
- *     &lt;enumeration value="Acceleration2DVideo"/>
  *     &lt;enumeration value="Acceleration3D"/>
  *   &lt;/restriction>
  * &lt;/simpleType>
@@ -28,8 +27,6 @@ public enum GraphicsFeature {
 
     @XmlEnumValue("None")
     NONE("None"),
-    @XmlEnumValue("Acceleration2DVideo")
-    ACCELERATION_2_D_VIDEO("Acceleration2DVideo"),
     @XmlEnumValue("Acceleration3D")
     ACCELERATION_3_D("Acceleration3D");
     private final String value;
